@@ -1,14 +1,11 @@
 #from .evaluate import evaluate
 
 from .PSO import Experiment
-from .PSO import find_optimal_constants
-
 from .PSO import read_dictionary_from_file
 from .PSO import write_dictionary_to_file
 from .PSO import determine_n_evaluations
 from .PSO import random_informants
 from .PSO import determine_error
-from .PSO import Training_session
 from .PSO import Particle
 from .PSO import Swarm
 from .PSO import evaluate
